#This script was written by Urszula Oszczapinska, Carnegie Mellon University Psychology PhD Student.
#Regard this script as supplementary material to paper: The underlying temporal features in the transition
#from bouncing and rolling. 

#Data is not provided. This script only contains general analysis framework.
#For any and all questions, please email: uoszczap@andrew.cmu.edu

#setting working directory
setwd("")

#loading packages
library(tidyverse)
library(quickpsy)
library(broom)
library(dplyr)
library(tidyr)
library(glmulti)
library(boot)
library(lme4)
library(jcolors)
library(DescTools)

#read in the data file; already tidy
df = read.csv("")
dat = df %>%
  select(-X)

#changing character to numeric (binary: 0 & 1s)
dat[dat == "Bouncing"] <- 0 #bounce = 0
dat[dat == "Rolling"] <- 1 #roll = 1

dat$rating <- as.numeric(dat$rating) #rating referring to the categorical response from binary task
dat$tempo <- as.factor(dat$tempo) #tempo referring to the initial III of SS_400, and SS_200

prop_dat = dat #proportion data frame

#setting up proportions
prop_dat <- prop_dat %>%
  group_by(id, tempo, INDEX) %>%  #INDEX refers to impulse sequence, tempo refers to Initial III, id is subject ID
  summarise(prop = mean(rating), roll = sum(rating), 
            n = n(), bounce = n-roll) 

mean_prop_dat = prop_dat %>%
  group_by(tempo, INDEX) %>%
  mutate(mean_rating = mean(prop), sd = sd(prop), SE = sd/sqrt()) #calculating averages; sample size is not included here for SE.

dat_orig = mean_prop_dat %>% #orig refers to C_400 
  select(-id, -prop, -roll, -n, -bounce) %>%
  filter(tempo == "original") %>% #original refers to C_400
  unique()

dat_fast = mean_prop_dat %>% #fast refers to C_200
  select(-id, -prop, -roll, -n, -bounce) %>%
  filter(tempo == "fast") %>% #fast refers to C_200
  unique()

########### PLOTTING ###########
library(drc) #DRC package

#graphs
ggplot(data = dat_orig, aes(x = INDEX, y = mean_rating)) +
  geom_point(size = 1.5, alpha = 1, shape = 1) + #data points
  geom_errorbar(dat_orig, mapping = aes(x = INDEX, ymax = mean_rating + SE, ymin = mean_rating - SE), width = 0.001, alpha = 0.009, color = "black", linetype = "solid") + #errorbars
  geom_smooth(method = drm, formula = y~x, method.args = list(fct = L.3()), se = FALSE, color = "black") + #fit
  geom_point(data = dat_fast, aes(x = INDEX, y = mean_rating), color = "black", alpha = 1) + #data points
  geom_errorbar(dat_fast, mapping = aes(x = INDEX, ymax = mean_rating + SE, ymin = mean_rating - SE), width = 0.001, alpha = 0.009, color = "black", linetype = "solid") + #errorbars
  geom_smooth(method = drm, formula = y~x, method.args = list(fct = L.3()), data = dat_fast, aes(x = INDEX, y = mean_rating), se = FALSE, color = "black", linetype = 2) + #fit
  xlab('') + #x-axis label
  ylab('') + #y-axis label
  ggtitle('') + #title of figure
  ylim(0, 0.2) + #y-axis range
  #scale_x_log10(limits = c(5, 1010)) + #log-scale when appropriate
  xlim(0.91, 1) + #if not log-scaled x-axis, then normal x-axis w/ range
  theme_linedraw() + #figure w/ certain theme
  theme(text = element_text(size = 12, family = "Helvetica")) #misc. details related to font and font size of text in figures

######### MODEL SELECTION ########
#setting the reference as original tempo
dat$tempo <- relevel(dat$tempo, ref = 2) #using C_400 as reference

#using a GLM fit on the data; automated subset selection function: glmulti
log.reg.fit = glmulti(y = "rating", xr = c("INDEX", "tempo"), data = dat, crit = "aic")
#summary(log.reg.fit)  #provides a summary of the exhaustive analysis
print(log.reg.fit)

#table displaying the models run, and respective AIC values
weightable(log.reg.fit)

m1 = glm(rating ~ 1, data = dat) 
m2 = glm(rating ~ 1 + tempo, data = dat)
m3 = glm(rating ~ 1 + INDEX, data = dat)
m4 = glm(rating ~ 1 + tempo + INDEX, data = dat)
m5 = glm(rating ~ 1 + tempo + INDEX + tempo*INDEX, data =dat)
##NOTE: 'drm' function instead of 'glm' function was used to compare across fits

anova(m1, m2, m3, m4, m5, test = "LR") #testing model significance

#best model
model = glm() #did the same with drm function to compare across fits
summary(model) #stats of the fit

#coefficients
b0 = summary(model)$coefficients[1]
b1 = summary(model)$coefficients[2]
